"use strict";
var async_1 = require('../../../serenity/recording/async');
var BrowseTheWeb = (function () {
    function BrowseTheWeb(browser) {
        this.browser = browser;
    }
    /**
     *
     * Instantiates the Ability to BrowseTheWeb, allowing the Actor to interact with a Web UI
     *
     * @param browser
     * @return {BrowseTheWeb}
     */
    BrowseTheWeb.using = function (browser) {
        return new BrowseTheWeb(browser);
    };
    /**
     * Used to access the Actor's ability to BrowseTheWeb from within the Interaction classes, such as Click or Enter
     *
     * @param actor
     * @return {BrowseTheWeb}
     */
    BrowseTheWeb.as = function (actor) {
        return actor.abilityTo(BrowseTheWeb);
    };
    BrowseTheWeb.prototype.locate = function (target) {
        return target.resolveUsing(this.browser.element);
    };
    BrowseTheWeb.prototype.locateAll = function (target) {
        return target.resolveAllUsing(this.browser.element); // see: https://github.com/angular/protractor/issues/3350
    };
    BrowseTheWeb.prototype.takeScreenshot = function () {
        var _this = this;
        return async_1.defer(function () { return _this.browser.takeScreenshot(); });
    };
    BrowseTheWeb.prototype.get = function (destination, timeout) {
        return this.browser.get(destination, timeout);
    };
    BrowseTheWeb.prototype.getTitle = function () {
        return this.browser.getTitle();
    };
    BrowseTheWeb.prototype.actions = function () {
        return this.browser.actions();
    };
    BrowseTheWeb.prototype.manage = function () {
        return this.browser.driver.manage();
    };
    return BrowseTheWeb;
}());
exports.BrowseTheWeb = BrowseTheWeb;

//# sourceMappingURL=browse_the_web.js.map
