"use strict";
(function (Result) {
    /**
     * Failures due to external events or systems that compromise the validity of the test.
     */
    Result[Result["COMPROMISED"] = 1] = "COMPROMISED";
    /**
     * Failure, due to some other exception.
     */
    Result[Result["ERROR"] = 2] = "ERROR";
    /**
     * Failure, due to an assertion error
     * For a test case, this means one of the tests in the test case failed.
     */
    Result[Result["FAILURE"] = 4] = "FAILURE";
    /**
     * The test step was not executed because a previous step in this test case failed.
     * A whole test case can be skipped using tags or annotations to indicate that it is currently "work-in-progress"
     */
    Result[Result["SKIPPED"] = 8] = "SKIPPED";
    /**
     * The test or test case was deliberately ignored.
     * Tests can be ignored via the @Ignore annotation in JUnit, for example.
     * Ignored tests are not considered the same as pending tests: a pending test is one that
     * has been specified, but the corresponding code is yet to be implemented, whereas an
     * ignored test can be a temporarily-deactivated test (during refactoring, for example).
     */
    Result[Result["IGNORED"] = 16] = "IGNORED";
    /**
     * A pending test is one that has been specified but not yet implemented.
     * In a JUnit test case, you can use the (Thucydides) @Pending annotation to mark this.
     * A pending test case is a test case that has at least one pending test.
     */
    Result[Result["PENDING"] = 32] = "PENDING";
    /**
     * The test or test case ran as expected.
     */
    Result[Result["SUCCESS"] = 64] = "SUCCESS";
    Result[Result["Failed"] = 7] = "Failed";
    Result[Result["Finished"] = 71] = "Finished";
})(exports.Result || (exports.Result = {}));
var Result = exports.Result;
var Tag = (function () {
    function Tag(type, values) {
        if (values === void 0) { values = []; }
        this.type = type;
        this.values = values;
    }
    Tag.from = function (text) {
        var _a = Tag.Pattern.exec(text), type = _a[1], values = _a[2];
        return new Tag(type, values.split(',').filter(function (_) { return _.length > 0; }).map(function (_) { return _.trim(); }));
    };
    Object.defineProperty(Tag.prototype, "value", {
        get: function () {
            return this.values.join(', ');
        },
        enumerable: true,
        configurable: true
    });
    Tag.Pattern = /^@([\w-]+)[:\s]?(.*)/i;
    return Tag;
}());
exports.Tag = Tag;
var Scene = (function () {
    function Scene(name, category, path, tags, id) {
        if (tags === void 0) { tags = []; }
        if (id === void 0) { id = category + ":" + name; }
        this.name = name;
        this.category = category;
        this.path = path;
        this.tags = tags;
        this.id = id;
    }
    Scene.prototype.toString = function () {
        return this.name + " (category: " + this.category + ", path: " + this.path + when(this.id !== this.name, ', id: ' + this.id) + ")";
    };
    return Scene;
}());
exports.Scene = Scene;
var Activity = (function () {
    function Activity(name, id) {
        if (id === void 0) { id = name; }
        this.name = name;
        this.id = id;
    }
    Activity.prototype.equals = function (another) {
        return this.name === another.name && this.id === another.id;
    };
    Activity.prototype.toString = function () {
        return "" + this.name + when(this.id !== this.name, ' (id: ' + this.id + ')');
    };
    return Activity;
}());
exports.Activity = Activity;
var Outcome = (function () {
    function Outcome(subject, result, error) {
        this.subject = subject;
        this.result = result;
        this.error = error;
    }
    Outcome.prototype.toString = function () {
        return this.subject.toString() + " (result: " + Result[this.result] + when(!!this.error, ', error:' + this.error) + ")";
    };
    return Outcome;
}());
exports.Outcome = Outcome;
var Photo = (function () {
    function Photo(path) {
        this.path = path;
    }
    return Photo;
}());
exports.Photo = Photo;
var PhotoReceipt = (function () {
    function PhotoReceipt(activity, photo) {
        this.activity = activity;
        this.photo = photo;
    }
    PhotoReceipt.prototype.toString = function () {
        return this.activity.toString();
    };
    return PhotoReceipt;
}());
exports.PhotoReceipt = PhotoReceipt;
function when(condition, value) {
    return condition ? value : '';
}

//# sourceMappingURL=model.js.map
